/**
XTC_MENU.h
	Conveniences for creating menu systems.
**/


typedef struct {
   Widget manager, cascade;
   char *name;
   Widget *items;
   int cur_child_count, cur_item_array_size;
} MenuRec, *Menu;



/** CREATING MENU BODIES
After opening a menu, add its items and then close.
**/   
Menu
XTCmenu_openPulldown (Widget parent, char *name);

Menu
XTCmenu_openSubmenu (Menu parentmenu, char *name);

void
XTCmenu_close (Menu menu);



/** ADDING ITEMS
The widgets for the items are auto-named "MENU_<menuname>_<index>",
   with <index> being 0 for the first item added.
Use the app-defaults to assign label strings to the menu items.
**/

void
XTCmenu_addItems (Menu menu, int count, void (*callback)());

#define XTCmenu_addItem(M,C)  XTCmenu_addItems(M,1,C)



/** CONTROLLING ITEM SENSITIVITY
The following functions and macros let you disable ("grey out") and enable
   menu items.
**/

void
XTCmenu_setItemSensitivity (Menu menu, int index, Boolean enable);

void
XTCmenu_setAllItemsSensitivity (Menu menu, Boolean enable);

#define XTCmenu_enableAllItems(M)    XTCmenu_setAllItemsSensitivity(M,TRUE)
#define XTCmenu_disableAllItems(M)   XTCmenu_setAllItemsSensitivity(M,FALSE)
#define XTCmenu_enableItem(M,I)        XTCmenu_setItemSensitivity(M,I,TRUE)
#define XTCmenu_disableItem(M,I)       XTCmenu_setItemSensitivity(M,I,FALSE)


/***** EXAMPLE USAGE:

C-CODE:

  menubar = XmCreateMenuBar (mainwin, "menubar", NULL, 0);
  XtManageChild (menubar);

  menuId_Login = XTCmenu_openPulldown (menubar, "Login");
  XTCmenu_addItems (menuId_Login, 2, ACTIVATE_login);
  XTCmenu_addItems (menuId_Login, 1, ACTIVATE_logout);
  XTCmenu_close (menuId_Login);
  
  menuId_Action = XTCmenu_openPulldown (menubar, "Action");
  submenu = XTCmenu_openSubmenu (menuId_Action, "Inquire");
    XTCmenu_addItems (submenu, 1, ACTIVATE_balance);
    XTCmenu_addItems (submenu, 2, ACTIVATE_distribution);
    XTCmenu_close (submenu);
  XTCmenu_addItems (menuId_Action, 1, ACTIVATE_withdraw);
  XTCmenu_addItems (menuId_Action, 1, ACTIVATE_transfer);
  XTCmenu_addItems (menuId_Action, 1, ACTIVATE_deposit);
  XTCmenu_addItems (menuId_Action, 1, ACTIVATE_changeInfo);
  XTCmenu_addItems (menuId_Action, 1, ACTIVATE_payBills);
  XTCmenu_close (menuId_Action);


RESOURCE-CODE:

*Login.mnemonic: L
*MENU_Login_0.labelString: Login for one task
*MENU_Login_0.mnemonic: o
*MENU_Login_1.labelString: Login for many tasks
*MENU_Login_1.mnemonic: m
*MENU_Login_2.labelString: Exit
*MENU_Login_2.mnemonic: x

*Action.mnemonic: A
*Inquire.mnemonic: I
*MENU_Action_1.labelString: Withdraw
*MENU_Action_1.mnemonic: W
*MENU_Action_2.labelString: Transfer
*MENU_Action_2.mnemonic: T
*MENU_Action_3.labelString: Deposit
*MENU_Action_3.mnemonic: D
*MENU_Action_4.labelString: Edit personal info
*MENU_Action_4.mnemonic: E
*MENU_Action_5.labelString: Pay bills
*MENU_Action_5.mnemonic: P

*MENU_Inquire_0.labelString: Simple balance query
*MENU_Inquire_1.labelString: Scalable pie chart
*MENU_Inquire_2.labelString: Scrollable pie chart

*****/
